Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BasicQueryParam ¶
type BasicQueryParam struct {
Paginator struct {
Page int
PageSize int
}
Filter struct {
OrederBy []string
}
}
BasicQueryParam should be used to param basic pagination and orderby queryparams
func NewBasicQueryParam ¶
func NewBasicQueryParam() *BasicQueryParam
type CreateAccountRequest ¶
type CreateAccountResponse ¶
type CreateAccountResponse struct {
UserID uint `json:"user_id,omitempty"`
Err error `json:"error,omitempty"`
}
func (CreateAccountResponse) Failed ¶
func (resp CreateAccountResponse) Failed() error
type CustomClaim ¶
type CustomClaim struct {
*stdjwt.StandardClaims
AccntID uint `json:"accnt_id"`
Email string `json:"email"`
Role string `json:"role"`
}
CustomClaim defines the claim to be used in JWT
type GetAccountResponse ¶
type ListAccountResponse ¶
type ListAccountResponse struct {
Accounts []GetAccountResponse `json:"accounts,omitempty"`
PageInfo *Page `json:"page,omitempty"`
Err error `json:"error,omitempty"`
}
func (ListAccountResponse) Failed ¶
func (resp ListAccountResponse) Failed() error
type LoginRequest ¶
type LoginResponse ¶
type LoginResponse struct {
AccessToken string `json:"access_token,omitempty"`
RefreshToken string `json:"refresh_token,omitempty"`
Err error `json:"err,omitempty"`
}
func (LoginResponse) Failed ¶
func (resp LoginResponse) Failed() error
Click to show internal directories.
Click to hide internal directories.