Documentation
¶
Index ¶
- func MakeCreateAccountEndpoint(s service.IAuthNService) endpoint.Endpoint
- func MakeDeleteAccountEndpoint(s service.IAuthNService) endpoint.Endpoint
- func MakeListAccountEndpoint(s service.IAuthNService) endpoint.Endpoint
- func MakeLoginEndpoint(s service.IAuthNService) endpoint.Endpoint
- func NewJWTTokenParsingMW(secretKey string) kitep.Middleware
- type Endpoints
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func MakeCreateAccountEndpoint ¶
func MakeCreateAccountEndpoint(s service.IAuthNService) endpoint.Endpoint
func MakeDeleteAccountEndpoint ¶
func MakeDeleteAccountEndpoint(s service.IAuthNService) endpoint.Endpoint
func MakeListAccountEndpoint ¶
func MakeListAccountEndpoint(s service.IAuthNService) endpoint.Endpoint
func MakeLoginEndpoint ¶
func MakeLoginEndpoint(s service.IAuthNService) endpoint.Endpoint
func NewJWTTokenParsingMW ¶
func NewJWTTokenParsingMW(secretKey string) kitep.Middleware
Types ¶
type Endpoints ¶
type Endpoints struct {
LoginEndpoint endpoint.Endpoint
// RenewAccessTokenEndpoint endpoint.Endpoint
// VerifyTokenEndpoint endpoint.Endpoint
// RevokeTokenEndpoint endpoint.Endpoint
CreateAccountEndpoint endpoint.Endpoint
ListAccountEndpoint endpoint.Endpoint
// GetUserEndpoint endpoint.Endpoint
// UpdateUserEndpoint endpoint.Endpoint
DeleteAccountEndpoint endpoint.Endpoint
}
Endpoints collects all of the endpoints that compose a profile service. It's meant to be used as a helper struct, to collect all of the endpoints into a single parameter.
func New ¶
func New(s service.IAuthNService, mdw map[string][]endpoint.Middleware) Endpoints
New returns a Endpoints struct that wraps the provided service, and wires in all of the expected endpoint middlewares
Click to show internal directories.
Click to hide internal directories.