Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BasicQueryParam ¶
type BasicQueryParam struct {
Paginator struct {
Page int
PageSize int
}
Filter struct {
OrederBy []string
}
}
BasicQueryParam should be used to param basic pagination and orderby queryparams
func NewBasicQueryParam ¶
func NewBasicQueryParam() *BasicQueryParam
type CreateOrderRequest ¶
type CreateOrderResponse ¶
type CreateOrderResponse struct {
OID uuid.UUID `json:"order_id,omitempty"`
Err error `json:"error,omitempty"`
}
func (CreateOrderResponse) Failed ¶
func (resp CreateOrderResponse) Failed() error
type CustomClaim ¶
type CustomClaim struct {
*stdjwt.StandardClaims
AccntID uint `json:"accnt_id"`
Email string `json:"email"`
Role string `json:"role"`
}
CustomClaim defines the claim to be used in JWT
type GetOrderResponse ¶
type ListOrderResponse ¶
type ListOrderResponse struct {
Orders []GetOrderResponse `json:"orders,omitempty"`
Err error `json:"error,omitempty"`
}
func (ListOrderResponse) Failed ¶
func (resp ListOrderResponse) Failed() error
Click to show internal directories.
Click to hide internal directories.