Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BasicQueryParam ¶
type BasicQueryParam struct {
Paginator struct {
Page int
PageSize int
}
Filter struct {
OrederBy []string
}
}
BasicQueryParam should be used to param basic pagination and orderby queryparams
func NewBasicQueryParam ¶
func NewBasicQueryParam() *BasicQueryParam
type CreateMerchantRequest ¶
type CreateMerchantRequest struct {
Name string `json:"name"`
}
type CreateMerchantResponse ¶
type CreateMerchantResponse struct {
ID uuid.UUID `json:"id,omitempty"`
Err error `json:"error,omitempty"`
}
func (CreateMerchantResponse) Failed ¶
func (resp CreateMerchantResponse) Failed() error
type CreateProductRequest ¶
type CreateProductResponse ¶
type CreateProductResponse struct {
ID uuid.UUID `json:"id,omitempty"`
Err error `json:"err,omitempty"`
}
func (CreateProductResponse) Failed ¶
func (resp CreateProductResponse) Failed() error
type CustomClaim ¶
type CustomClaim struct {
*stdjwt.StandardClaims
AccntID uint `json:"accnt_id"`
Email string `json:"email"`
Role string `json:"role"`
}
CustomClaim defines the claim to be used in JWT
type ListMerchantResponse ¶
type ListMerchantResponse struct {
Merchants []MerchantDetailResponse `json:"merchants,omitempty"`
Err error `json:"err,omitempty"`
}
func (ListMerchantResponse) Failed ¶
func (resp ListMerchantResponse) Failed() error
type ListProductResponse ¶
type ListProductResponse struct {
Products []ProductDetailsResponse `json:"products,omitempty"`
Err error `json:"error,omitempty"`
}
func (ListProductResponse) Failed ¶
func (resp ListProductResponse) Failed() error
type MerchantDetailResponse ¶
type ProductDetailsResponse ¶
Click to show internal directories.
Click to hide internal directories.